TimerConfig

Struct TimerConfig 

pub struct TimerConfig {
    pub clock_source: ClockSource,
    pub direction: CountDirection,
    pub resolution: Hertz,
    pub intr_priority: i32,
    pub intr_shared: bool,
    pub allow_pd: bool,
    /* private fields */
}
Configuration for TimerDriver

Fields

clock_source: ClockSource

GPTimer clock source

direction: CountDirection

Count direction

resolution: Hertz

Counter resolution (working frequency) in Hz, hence, the step size of each count tick equals to (1 / resolution_hz) seconds

intr_priority: i32

GPTimer interrupt priority, if set to 0, the driver will try to allocate an interrupt with a relative low priority (1,2,3)

intr_shared: bool

If set true, the timer interrupt number can be shared with other peripherals

allow_pd: bool

If set, driver allows the power domain to be powered off when system enters sleep mode. This can save power, but at the expense of more RAM being consumed to save register context.