pub struct TimerConfig {
pub clock_source: ClockSource,
pub direction: CountDirection,
pub resolution: Hertz,
pub intr_priority: i32,
pub intr_shared: bool,
pub allow_pd: bool,
/* private fields */
}Expand description
Configuration for TimerDriver
Fields
clock_source: ClockSourceGPTimer clock source
direction: CountDirectionCount direction
resolution: HertzCounter resolution (working frequency) in Hz, hence, the step size of each count tick equals to (1 / resolution_hz) seconds
intr_priority: i32GPTimer interrupt priority, if set to 0, the driver will try to allocate an interrupt with a relative low priority (1,2,3)
If set true, the timer interrupt number can be shared with other peripherals
allow_pd: boolIf set, driver allows the power domain to be powered off when system enters sleep mode. This can save power, but at the expense of more RAM being consumed to save register context.